"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
const path = require("node:path");
const cssVarExtract = require("css-var-extract");
let lock = false;
const checkLock = () => lock;
const setLock = (bool) => {
  lock = bool;
};
const unpluginCssVarExtractFactory = (options) => {
  let root = process.cwd();
  let userConfig = options;
  const getFilePaths = () => userConfig.files.map(
    (file) => path.isAbsolute(file) ? file : path.join(root, file)
  );
  const generate = async () => {
    if (checkLock()) {
      return;
    }
    setLock(true);
    try {
      await cssVarExtract.generator(userConfig);
    } catch (err) {
      console.error(err);
      console.info();
    } finally {
      setLock(false);
    }
  };
  const handleFile = async (file, event) => {
    const filePath = path.normalize(file);
    if (filePath === path.join(root, "cve.config.json")) {
      userConfig = cssVarExtract.getConfig(true, userConfig, root);
      return;
    }
    if (event === "update" && filePath === path.resolve(userConfig.output)) {
      return;
    }
    if (getFilePaths().includes(filePath)) {
      await generate();
    }
  };
  return {
    name: "router-generator-plugin",
    async watchChange(id, { event }) {
      await handleFile(id, event);
    },
    vite: {
      async configResolved(config) {
        root = config.root;
        userConfig = cssVarExtract.getConfig(true, userConfig, root);
        await generate();
      }
    },
    async rspack(compiler) {
      userConfig = cssVarExtract.getConfig(true, userConfig, root);
      if (compiler.options.mode === "production") {
        await generate();
      } else {
        const filePaths = getFilePaths();
        const chokidar = await import("chokidar");
        chokidar.watch(filePaths).on("add", async () => {
          await generate();
        });
      }
    },
    async webpack(compiler) {
      userConfig = cssVarExtract.getConfig(true, userConfig, root);
      if (compiler.options.mode === "production") {
        await generate();
        compiler.hooks.done.tap("unplugin:css-var-extract", () => {
          console.info(
            "✅ unplugin:css-var-extract: generation done"
          );
          setTimeout(() => {
            process.exit(0);
          });
        });
      } else {
        const filePaths = getFilePaths();
        const chokidar = await import("chokidar");
        chokidar.watch(filePaths).on("add", async () => {
          await generate();
        });
      }
    }
  };
};
exports.unpluginCssVarExtractFactory = unpluginCssVarExtractFactory;
//# sourceMappingURL=css-var-extract-plugin-wG1ltKUR.cjs.map
